==> rheolef_7.1.orig.tar.gz: rheolef-7.1/linalg/tst/disarray_io_tst.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
SRCDIR=${SRCDIR-"."}
TOP_SRCDIR=${TOP_SRCDIR-"../.."}
NPROC_MAX=${NPROC_MAX-"7"}
. "${TOP_SRCDIR}/config/loop_mpirun.sh"

if test "$QD_EXT" = ".float128"; then QD_EXT=""; fi

status=0

loop_mpirun "./disarray_io_tst  < ${SRCDIR}/disarray_set_tst${QD_EXT}.out.valid 2> /dev/null | \
diff ${SRCDIR}/disarray_set_tst${QD_EXT}.out.valid - >/dev/null"
if test $? -ne 0; then status=1; fi

i=5;
while test ${i} -ne 0; do
  run "echo | LANG=C gawk -v n=${i} -f ${SRCDIR}/gen_vec${QD_EXT}.awk > vec-${i}.dat"
  if test $? -ne 0; then status=1; break; fi

  loop_mpirun "./disarray_io_tst < vec-${i}.dat 2>/dev/null | diff -B -w - vec-${i}.dat >/dev/null"
  if test $? -ne 0; then status=1; fi

  run "rm -f vec-${i}.dat"
  if test $? -ne 0; then status=1; break; fi
  i=`expr ${i} - 1`
done

exit $status

==> rheolef_7.2.orig.tar.gz: rheolef-7.2/linalg/tst/disarray_io_tst.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
SRCDIR=${SRCDIR-"$TOP_SRCDIR/linalg/tst"}
NPROC_MAX=${NPROC_MAX-"7"}
. "${TOP_SRCDIR}/config/loop_mpirun.sh"

if test "$QD_EXT" = ".float128"; then QD_EXT=""; fi

status=0

loop_mpirun "./disarray_io_tst  < ${SRCDIR}/disarray_set_tst${QD_EXT}.out.valid 2> /dev/null | \
diff ${SRCDIR}/disarray_set_tst${QD_EXT}.out.valid - >/dev/null"
if test $? -ne 0; then status=1; fi

i=5;
while test ${i} -ne 0; do
  run "echo | LANG=C gawk -v n=${i} -f ${SRCDIR}/gen_vec${QD_EXT}.awk > vec-${i}.dat"
  if test $? -ne 0; then status=1; break; fi

  loop_mpirun "./disarray_io_tst < vec-${i}.dat 2>/dev/null | diff -B -w - vec-${i}.dat >/dev/null"
  if test $? -ne 0; then status=1; fi

  run "rm -f vec-${i}.dat"
  if test $? -ne 0; then status=1; break; fi
  i=`expr ${i} - 1`
done

exit $status
